pub fn explain_finding(root: &Path, selector: &str) -> Result<String, String>Expand description
Analyze a workspace diff using the default RIPR static pipeline. Computes findings and renders a single selected finding in human format.
The selector can be either a finding identifier (for example
probe:path_to_file.rs:42:family) or a file:line location.